#
# spec file for package python-testpath
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-testpath
Version:        0.6.0
Release:        2.6
Summary:        Test utilities for code working with files and commands
License:        BSD-3-Clause OR LGPL-2.1-or-later
Group:          Development/Languages/Python
URL:            https://github.com/jupyter/testpath
Source0:        https://files.pythonhosted.org/packages/source/t/testpath/testpath-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Testpath is a collection of utilities for Python code working with
files and commands.

It contains functions to check things on the filesystem, and tools
for mocking system commands and recording calls to those.

%prep
%setup -q -n testpath-%{version}

rm testpath/*.exe

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/testpath/
%{python_sitelib}/testpath-%{version}*-info

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Sat Feb 26 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * switch to pyproject toml build
- update to version 0.6.0:
  * Removed some code that’s unused since dropping Python 2 support.
  * Relax the version constraint for the flit_core build requirement.
* Wed Oct 20 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.5.0
  * Easier ways to use `MockCommand` to customise mocked commands,
  including `python=` to specify extra code to run,
  `.MockCommand.fixed_output`, and `.MockCommand.assert_called`.
  * Command mocking will use `os.defpath` as the initial PATH if the
  PATH environment variable is not set.
- Drop Python 2 build
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.4.4
  * Add Python 3.7 and 3.8 on Travis CI
- Update to version 0.4.3
  * Use path-like protocol for path objects where supported
* Sat Apr  6 2019 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary Windows executables
- Activate test suite
* Thu Oct 11 2018 Todd R <toddrme2178@gmail.com>
- Update to version 0.4.2:
  * Copyright fixes
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Update to version 0.4.1:
  * Don't error if we can't clean up command directory
  * Comment test requirement; bug in flit prevents upload with it
- Update to version 0.4.0:
  * Convert dev-requires to 'test' extra requirements
  * Add doc URL
  * Convert flit.ini to pyproject.toml
  * Fix bitness selection for Windows exe
  * Group related operations together
  * Ignore pytest cache dir
  * Separate command dir for each MockCommand
  * Remove python_requires
  * Remove x.y classifiers
  * Add support for Python 3.5-3.6
  * Drop support for EOL Python 3.3
  * correct spelling mistake
  * Document new assertion functions
  * Add support for named pipes and sockets
* Thu Jan 18 2018 toddrme2178@gmail.com
- Fix files list
* Thu Nov  2 2017 arun@gmx.de
- changed to tar-ball version
* Sun Oct 22 2017 arun@gmx.de
- update to version 0.3.1:
  * Add dev requirement on pathlib2
  * Use pathlib2 instead of pathlib
  * Convert readthedocs links for their .org -> .io migration for
    hosted projects
* Mon Apr 24 2017 toddrme2178@gmail.com
- Switch to wheel-based install.
- Implement single-spec version.
* Thu Apr  6 2017 toddrme2178@gmail.com
- specfile:
  * update copyright year
  * LICENSE file is now in tar-ball
- update to version 0.3:
  (no changelog available)
* Fri Jan 29 2016 toddrme2178@gmail.com
- Don't use flit (which doesn't work reliably),
  just copy the sources to the right place.
* Wed Oct 14 2015 toddrme2178@gmail.com
- Add LICENSE file from upstream github project.
* Tue Sep 29 2015 toddrme2178@gmail.com
- Initial version
